@@ -65,7 +65,10 @@ sj_playlist = {
         'kind': {'type': 'string'},
         'name': {'type': 'string'},
         'deleted': {'type': 'boolean'},
-        'type': {'type': 'string', 'required': False},
+        'type': {'type': 'string',
+                 'pattern': r'MAGIC|SHARED|USER_GENERATED',
+                 'required': False,
+                 },
         'lastModifiedTimestamp': {'type': 'string'},
         'recentTimestamp': {'type': 'string'},
         'shareToken': {'type': 'string'},
